@@ -70,6 +70,9 @@ class Entity():
 
         if self.initialized:
             self._component_manager.create_component(value)
+            
+    def __delitem__(self, key):
+        self._components.pop(key)
 
     def __getattr__(self, key):
         if key in super().__getattribute__('__slots__'):
@@ -89,6 +92,9 @@ class Entity():
 
             if self.initialized:
                 self._component_manager.create_component(value)
+                
+    def __delattr__(self, key):
+        self._components.pop(key)
 
 
     def create(self, entity_manager, component_manager):
